diff --git a/course/social.php b/course/social.php
index 590eb9c3d62..c2c92211b8b 100644
--- a/course/social.php
+++ b/course/social.php
@@ -23,21 +23,16 @@
print_side_block("", $moddata, "", $modicon);
- // Then, print all the available readings
-
+ // Then, print all the available resources (Section 0)
print_simple_box("Resources", $align="CENTER", $width="100%", $color="$THEME->cellheading");
+ print_section($site->id, $sections[0], $mods, $modnamesused, true);
- if ($readings = reading_list_all_readings($course->id, "timemodified DESC", 0, true)) {
- foreach ($readings as $reading) {
- $readingdata[] = $reading;
- $readingicon[] = "
";
- }
- }
- if (isediting($course->id)) {
- $readingdata[] = "id§ion=0&add=reading\">Add reading...";
- $readingicon[] = " ";
- }
- print_side_block("", $readingdata, "", $readingicon);
+ if (isediting($site->id)) {
+ echo "